C Erster Entwurf fr eine UAMP-Subroutine:
C
C	Definition der 'Input-Parameter':
C
C	ampName		-		User-specified amplitude name, left justified. 
C	time		-		Current value of step time.		
C	ampValueOld	-		Old value of the amplitude from the previous increment.
C	dt			-		Current stable time increment.
C	nSvars		-		User-defined number of solution-dependent state variables associated with this amplitude definition.
C	svars		-		An array containing the values of the solution-dependent state variables associated with this amplitude definition. 
C						The number of such variables is nsvars (see above). You define the meaning of these variables.
C						This array is passed into UAMP containing the values of these variables at the start of the current increment. 
C						In most cases they should be updated to be the values at the end of the increment.
C	lFlagsInfo	-		Integer flag array with information regrading the current call to UAMP.
C	nSensor				-		Total number of sensors in the model.
C	sensorValues		-		Array with sensor values at the end of the previous increment. Each sensor value corresponds to a history output 
C								variable associated with the output database request defining the sensor.
C	sensorNames			-		Array with user-defined sensor names in the entire model, left justified. Each sensor name corresponds to a sensor 
C								value provided with the output database request. All names will be converted to uppercase characters if lowercase 
C								or mixed-case characters were used in their definition.
C	jSensorLookUpTable	-		Variable that must be passed into the utility functions IGETSENSORID and GETSENSORVALUE.
C
C	Definition der 'Output-Parameter':
C
C	ampValueNew			-		Current value of the amplitude.
C   lFlagsDefine  		-		Integer flag array to determine whether the computation of additional quantities is necessary or to set step continuation requirements.
C	AmpDerivative		-		Current value of the amplitude derivative.					-> Berechnung via lFlagsDefine(iComputeDeriv) = 0
C	AmpSecDerivative	-		Current value of the amplitude second derivative.			-> Berechnung via lFlagsDefine(iComputeSecDeriv) = 0
C	AmpIncIntegral		-		Current value of the amplitude incremental integral.		-> Berechnung via lFlagsDefine(iComputeInteg) = 0
C	AmpDoubleIntegral	-		Current value of the amplitude incremental double integral.	-> Berechnung via lFlagsDefine(iComputeDoubleInteg) = 0
C
C	Hinweis: Fr 'lFlagsDefine(...) = 0' berechnet ABAQUS die bentigten Ableitungen, Integrale, etc. automatisch!
C
C	Start des Subroutine:
C
      SUBROUTINE UAMP(ampName, time, ampValueOld, dt, nSvars, 
     1 FlagsInfo, nSensor, sensorValues, sensorNames, 
     2 svars, jSensorLookUpTable, ampValueNew, lFlagsDefine, 
     3 AmpDerivative, AmpSecDerivative, AmpIncIntegral, 
     4 AmpDoubleIntegral) 
C
      INCLUDE 'ABA_PARAM.INC'     
C     
C  	Time indices:
C
      PARAMETER (iStepTime = 1,  
     1 iTotalTime = 2, 
     2 nTime = 2) 
C
C   	Flags passed in for information:
C
      PARAMETER (iInitialization = 1, 
     1 iRegularInc = 2, 
     2 iCuts = 3, 
     3 ikStep = 4, 
     4 nFlagsInfo = 4) 
C
C 	Optional flags to be defined:
C
      PARAMETER (iComputeDeriv = 1, 
     1 iComputeSecDeriv = 2, 
     2 iComputeInteg = 3, 
     3 iComputeDoubleInteg = 4, 
     4 iStopAnalysis = 5, 
     5 iConcludeStep = 6, 
     6 nFlagsDefine = 6)	   
C
      DIMENSION time(nTime), lFlagsInfo(nFlagsInfo), 
	1 lFlagsDefine(nFlagsDefine)
      DIMENSION jSensorLookUpTable(*)
      DIMENSION sensorValues(nSensor), svars(nSvars)
      CHARACTER*80 sensorNames(nSensor)
      CHARACTER*80 ampName
C
C	User coding to define 'AmpValueNew':
C
C	Get Sensor-Values:
C
      RF_SENSOR_IMP = GETSENSORVALUE('SENSOR', 
     1 jSensorLookUpTable)
      RF_SENSOR = sensorValues(RF_SENSOR_IMP)
C
      IF(lFlagsInfo(iInitialization) .EQ. 1) THEN
      	  ampValueNew = 0.0
      	  lFlagsDefine(iConcludeStep) = 0
      ELSE
      	  IF(RF_SENSOR .GE. 200) THEN
      	  	  lFlagsDefine(iConcludeStep) = 1
      	  END IF
      END IF
C
      RETURN
      END